﻿using Grpc.Core;
using Microsoft.Extensions.Caching.Memory;
using Resources;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Threading.Tasks;

namespace StatisticsService.Api.Clients
{
    public class CachedResourceProviderClient : ICachedResourceProviderClient
    {
        private readonly IMemoryCache cache;
        private readonly ResourceProvider.ResourceProviderClient client;

        public CachedResourceProviderClient(IMemoryCache cache, ResourceProvider.ResourceProviderClient client)
        {
            this.cache = cache;
            this.client = client;
        }

        public async IAsyncEnumerable<Resource> GetResourceBatchAsync(GetResourceRequestBatch batchRequest)
        {
            List<Resource> resourceResultList = new();
            List<string> resourceIdsNotCached = new();
            var resourceIds = batchRequest.Requests.Select(r => r.ResourceId);
            foreach (var resourceId in resourceIds)
            {
                if (cache.TryGetValue(resourceId, out Resource resource))
                {
                    yield return resource;
                }
                else
                {
                    resourceIdsNotCached.Add(resourceId);
                }
            }

            if (resourceIdsNotCached.Count > 0)
            {
                var request = new GetResourceRequestBatch();
                request.Requests.AddRange(resourceIdsNotCached.Select(r => new GetResourceRequest { ResourceId = r }));

                var response = client.GetResourceBatch(request);
                var resourceListResponse = response.ResponseStream.ReadAllAsync();

                var cacheEntryOptions = new MemoryCacheEntryOptions()
                    .SetAbsoluteExpiration(TimeSpan.FromHours(24));

                await foreach (var resourceResponse in resourceListResponse)
                {
                    cache.Set(resourceResponse.Id, resourceResponse, cacheEntryOptions);
                    yield return resourceResponse;
                }
            }
        }
    }
}
