﻿using MediatR;
using Microsoft.AspNetCore.Authorization;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.ModelBinding;
using StatisticsService.Domain.Filters;
using StatisticsService.Domain.Queries;
using StatisticsService.Dto;
using ZData.Iam.Enforcer.Client;


namespace StatisticsService.Api.Controllers
{
    [Route("api/v1/accounts")]
    [ApiController]
    [Authorize]
    public class AccountsController : ControllerBase
    {
        private readonly IEnforcer enforcer;
        private readonly IMediator mediator;

        public AccountsController(IEnforcer enforcer, IMediator mediator)
        {
            this.enforcer = enforcer;
            this.mediator = mediator;
        }

        /// <summary>
        /// Gets all active accounts
        /// </summary>
        /// <remarks>Returns a list of dates with counts of all active accounts within requested date range.</remarks>
        [HttpGet]
        public async Task<ActionResult<ActiveResourceDto>> GetActiveAccounts([FromQuery] BaseFilter filter)
        {
            var accounts = await mediator.Send(new GetActiveAccountsQuery(filter));

            if (accounts == null)
                return NotFound();

            return Ok(accounts);
        }

        /// <summary>
        /// Gets all active accounts associated with a resource ID
        /// </summary>
        /// <remarks>Returns a list of dates with counts of active accounts associated with requested resource within requested date range.</remarks>
        [HttpGet("{ResourceId}")]
        public async Task<ActionResult<ActiveResourceDto>> GetActiveAccountsByResourceId([FromQuery, BindRequired] BaseFilterRID filter)
        {
            var accounts = await mediator.Send(new GetActiveAccountsByResourceIdQuery(filter));

            if (accounts == null)
                return NotFound();

            return Ok(accounts);
        }

    }
}
