﻿using StatisticsService.Database;
using StatisticsService.Dto;
using StatisticsService.Api.Repository.Mock;
using StatisticsService.Database.Models;
using ZData.AccessServer.Client;

namespace StatisticsService.Api.Repository
{
    public class BaseRepository
    {       
        /// <summary>
        /// Temporary list of user mock data
        /// </summary>
        protected List<User> Users { get; }
        /// <summary>
        /// Temporary list of mock data of statistics with account numbers by day, as it does not exist on current model
        /// </summary>
        protected List<StatisticsDto> StatisticsAccountDay { get; }
        /// <summary>
        /// Temporary list of mock data of statistics with account numbers by hour, as it does not exist on current model
        /// </summary>
        protected List<StatisticsDto> StatisticsAccountHour { get; }

        /// <summary>
        /// Database context
        /// </summary>
        protected StatisticsServiceDbContext Context { get; }

        /// <summary>
        /// ZData Access Management Client
        /// </summary>
        protected IZamManagementClient ZamManagementClient { get; } = null!;

        /// <summary>
        /// Repository for common values across repositories.
        /// </summary>
        public BaseRepository(StatisticsServiceDbContext context)
        {
            Context = context;
            Users = RepositoryMockData.AddMockUsers();
            StatisticsAccountDay = RepositoryMockData.AddMockStatisticsDayAccountNumber();
            StatisticsAccountHour = RepositoryMockData.AddMockStatisticsHourAccountNumber();
        }
        public BaseRepository(StatisticsServiceDbContext context, IZamManagementClient zamManagementClient)
        {
            Context = context;
            ZamManagementClient = zamManagementClient;
            Users = RepositoryMockData.AddMockUsers();
            StatisticsAccountDay = RepositoryMockData.AddMockStatisticsDayAccountNumber();
            StatisticsAccountHour = RepositoryMockData.AddMockStatisticsHourAccountNumber();
        }

        /// <summary>
        /// Returns all childrens of a resource, used to get childrens for partner resource
        /// Uses ZAM to get permissions for apikey (partner)
        /// </summary>
        /// <param name="resourceId">ID of resource</param>
        /// <param name="resourceType">Type of resource</param>
        /// <returns>List of childrens to a partner resource, </returns>
        public async Task<IEnumerable<string>> GetResourceChildrensByResourceId(string resourceId, string resourceType)
        {
            var resourceIds = Enumerable.Empty<string>();
            if (resourceType == Constants.Resources.Partner)
            {
                var permissions = await ZamManagementClient.GetPermissionsForSubject($"apikey-{resourceId}", true, 0, ObjectModel.COMPANY, "bankservice", ActionModel.READ);
                resourceIds = permissions.Items.Select(p => p[2][(p[2].IndexOf("-") + 1)..]);
            } else
            {
                resourceIds = new string[] { resourceId };
            }

            return resourceIds;
        }
    }
}
