﻿using StatisticsService.Api.Extensions.QueryExtensions;
using StatisticsService.Database;
using StatisticsService.Domain.Filters;
using StatisticsService.Dto;
using StatisticsService.Interfaces.Repository;
using ZData.AccessServer.Client;

namespace StatisticsService.Api.Repository
{
    public class ClientsRepository : BaseRepository, IClientsRepository
    {
        /// <summary>
        /// Constructor
        /// </summary>
        public ClientsRepository(StatisticsServiceDbContext context) : base(context) { }
        public ClientsRepository(StatisticsServiceDbContext context, IZamManagementClient zamManagementClient) : base(context, zamManagementClient) { }

        public async Task<ActiveResourceDto> GetActiveClientsByResourceId(BaseFilterRID filter)
        {
            var resourceIds = await GetResourceChildrensByResourceId(filter.ResourceId, filter.ResourceType);

            var daily = await Context.AggregatedEventsDay
                .Where(x => resourceIds.Any(resourceId => resourceId == x.TopicId))
                .GetDailyActiveClientsFromQueryAsync(filter);

            var total = await Context.AggregatedEventsDay
                .Where(x => resourceIds.Any(resourceId => resourceId == x.TopicId))
                .GetTotalActiveClientsFromQueryAsync(filter);

            return new ActiveResourceDto(daily, total);
        }

        public async Task<ActiveResourceDto> GetAllActiveClients(BaseFilter filter)
        {
            var daily = await Context.AggregatedEventsDay
                .GetDailyActiveClientsFromQueryAsync(filter);

            var total = await Context.AggregatedEventsDay
                .GetTotalActiveClientsFromQueryAsync(filter);

            return new ActiveResourceDto(daily, total);
        }
    }
}
