﻿using MediatR;
using StatisticsService.Domain.Queries;
using StatisticsService.Dto;
using StatisticsService.Interfaces.Repository;
using System.Collections.Generic;
using System.Threading;
using System.Threading.Tasks;

namespace StatisticsService.Domain
{
    public class AccountsService : IRequestHandler<GetActiveAccountsByResourceIdQuery, ActiveResourceDto>,
                                   IRequestHandler<GetActiveAccountsQuery, ActiveResourceDto>
    {
        private readonly IAccountsRepository accountsRepository;
        public AccountsService(IAccountsRepository accountsRepository)
        {
            this.accountsRepository = accountsRepository;
        }

        public async Task<ActiveResourceDto> Handle(GetActiveAccountsByResourceIdQuery query, CancellationToken cancellationToken)
        {
            return await accountsRepository.GetActiveAccountsByResourceId(query.Filter);
        }

        public async Task<ActiveResourceDto> Handle(GetActiveAccountsQuery query, CancellationToken cancellationToken)
        {
            return await accountsRepository.GetAllActiveAccounts(query.Filter);
        }
    }
}
