﻿using MediatR;
using StatisticsService.Constants;
using StatisticsService.Domain.Queries;
using StatisticsService.Dto;
using StatisticsService.Interfaces.Repository;
using System;
using System.Collections.Generic;
using System.Threading;
using System.Threading.Tasks;

namespace StatisticsService.Domain
{
    public class StatisticsService : IRequestHandler<GetStatisticsByResourceQuery, IEnumerable<StatisticsDto>>,
                                     IRequestHandler<GetStatisticsQuery, IEnumerable<StatisticsDto>>,
                                     IRequestHandler<GetAggregatedStatisticsByResourceQuery, IEnumerable<AggregatedStatisticsDto>>,
                                     IRequestHandler<GetAggregatedStatisticsQuery, IEnumerable<AggregatedStatisticsDto>>,
                                     IRequestHandler<GetAllEventTypesQuery, IEnumerable<string>>
    {
        private readonly IStatisticsRepository statisticsRepository;
        public StatisticsService(IStatisticsRepository statisticsRepository)
        {
            this.statisticsRepository = statisticsRepository;
        }

        public async Task<IEnumerable<StatisticsDto>> Handle(GetStatisticsByResourceQuery query, CancellationToken cancellationToken)
        {
            return await statisticsRepository.GetStatisticsByResource(query.Filter);
        }

        public async Task<IEnumerable<StatisticsDto>> Handle(GetStatisticsQuery query, CancellationToken cancellationToken)
        {
            return await statisticsRepository.GetStatistics(query.Filter);
        }

        public async Task<IEnumerable<AggregatedStatisticsDto>> Handle(GetAggregatedStatisticsByResourceQuery query, CancellationToken cancellationToken)
        {
            return await statisticsRepository.GetAggregatedStatisticsByResource(query.Filter);
        }

        public async Task<IEnumerable<AggregatedStatisticsDto>> Handle(GetAggregatedStatisticsQuery query, CancellationToken cancellationToken)
        {
            return await statisticsRepository.GetAggregatedStatistics(query.Filter);
        }

        public async Task<IEnumerable<string>> Handle(GetAllEventTypesQuery query, CancellationToken cancellationToken)
        {
            return await Events.AllEventTypesAsync;
        }
    }
}