﻿using MediatR;
using StatisticsService.Domain.Queries;
using StatisticsService.Dto;
using StatisticsService.Interfaces.Repository;
using System.Collections.Generic;
using System.Threading;
using System.Threading.Tasks;

namespace StatisticsService.Domain
{
    public class UsersService : IRequestHandler<GetAllUsersQuery, IEnumerable<UserDto>>,
                                    IRequestHandler<GetUsersByResourceIdQuery, IEnumerable<UserDto>>,
                                    IRequestHandler<GetActiveUsersByResourceIdQuery, ActiveResourceDto>,
                                    IRequestHandler<GetAllActiveUsersQuery, ActiveResourceDto>
    {
        private readonly IUsersRepository usersRepository;
        public UsersService(IUsersRepository usersRepository)
        {
            this.usersRepository = usersRepository;
        }

        public async Task<IEnumerable<UserDto>> Handle(GetAllUsersQuery query, CancellationToken cancellationToken)
        {
            return await usersRepository.GetAllUsers(query.Filter);
        }

        public async Task<IEnumerable<UserDto>> Handle(GetUsersByResourceIdQuery query, CancellationToken cancellationToken)
        {
            return await usersRepository.GetUsersByResourceId(query.Filter);
        }

        public async Task<ActiveResourceDto> Handle(GetActiveUsersByResourceIdQuery query, CancellationToken cancellationToken)
        {
            return await usersRepository.GetActiveUsersByResourceId(query.Filter);
        }

        public async Task<ActiveResourceDto> Handle(GetAllActiveUsersQuery query, CancellationToken cancellationToken)
        {
            return await usersRepository.GetAllActiveUsers(query.Filter);
        }
    }
}