import { ReactChild, ReactChildren } from 'react'
import { useAuth } from 'react-oidc-context'
import { User } from 'oidc-client-ts'

import { UnauthorizedPage } from './pages/Unauthorized'
import { LoadingIndicator } from './components/LoadingIndicator'
import { isAdmin } from 'utils/auth'
import { useAuthStore } from 'store'

interface AdminSecureProps {
  children: ReactChild[] | ReactChildren
}

let isLoading = false

export const AdminSecure = ({ children }: AdminSecureProps) => {
  const auth = useAuth()
  const setAccessToken = useAuthStore(state => state.setAccessToken)

  setAccessToken(auth.user?.access_token ?? '')

  if (auth.error) {
    return (
      <div className="container d-flex justify-content-center align-items-center flex-column h-100vh">
        <p>Oops... {auth.error.message}</p>
        <button className="btn btn-primary btn-sm mt-3" onClick={() => auth.signinRedirect()}>
          Retry
        </button>
      </div>
    )
  }

  if (!auth.isLoading && !auth.isAuthenticated && auth.settings.authority !== '' && !isLoading) {
    auth.signinRedirect()
    isLoading = true
  }

  if (auth.isLoading) return <LoadingIndicator noPadding />

  return auth.isAuthenticated && isAdmin(auth.user as User) ? <>{children}</> : <UnauthorizedPage />
}
