import { ReactChildren, ReactChild } from 'react'
import { BrowserRouter as Router } from 'react-router-dom'
import { AuthProvider } from 'react-oidc-context'
import { HelmetProvider } from 'react-helmet-async'
import { QueryClient, QueryClientProvider } from 'react-query'
import { ReactQueryDevtools } from 'react-query/devtools'

import { useThemeStore } from 'store'
import configuration from 'utils/auth/configuration'

interface RootProps {
  children: ReactChild | ReactChildren
}

const queryClient = new QueryClient()

export const Root = ({ children }: RootProps) => {
  const isDarkMode = useThemeStore(state => state.isDarkMode)
  if (isDarkMode) {
    document.body.classList.add('dark-mode')
  } else {
    document.body.classList.remove('dark-mode')
  }
  return (
    <AuthProvider {...configuration}>
      <QueryClientProvider client={queryClient}>
        <HelmetProvider>
          <Router>{children}</Router>
          <ReactQueryDevtools />
        </HelmetProvider>
      </QueryClientProvider>
    </AuthProvider>
  )
}
