import { ReactElement, cloneElement } from 'react'
import { NavLink } from 'react-router-dom'
import { Aperture, CreditCard, Home, Package } from 'react-feather'

import { toggleSidebar } from 'utils'

interface Menu {
  name: string
  childrens: MenuChildren[]
}

interface MenuChildren {
  name: string
  url: string
  logo: ReactElement
  disabled?: boolean // remove when Control is implemented
}

const menus: Menu[] = [
  {
    name: 'Home',
    childrens: [
      {
        name: 'Dashboard',
        url: '/dashboard',
        logo: <Home />,
      },
    ],
  },
  {
    name: 'Projects',
    childrens: [
      {
        name: 'Bank Service',
        url: '/projects/bankservice',
        logo: <Package />,
      },
      {
        name: 'Settlement',
        url: '/projects/settlement',
        logo: <CreditCard />,
      },
      {
        name: 'Control',
        url: '/projects/control_',
        logo: <Aperture style={{ color: 'gray' }} />,
        disabled: true,
      },
    ],
  },
]

interface SideMenuIconProps {
  icon: ReactElement
}

const SideMenuIcon = ({ icon }: SideMenuIconProps) => {
  return cloneElement(icon, {
    className: 'side-menu__icon',
  })
}

export const SideMenu = () => {
  return (
    <ul className="side-menu">
      {menus.map((menu, index) => {
        return (
          <div key={index}>
            <li className="sub-category">
              <h3>{menu.name}</h3>
            </li>
            {menu.childrens.map((children, childrenIndex) => {
              return (
                <li key={childrenIndex} className="slide">
                  <NavLink
                    to={children.url}
                    className={({ isActive }) =>
                      'side-menu__item' +
                      (isActive ? ' active' : '') +
                      (children.disabled ? ' disabled' : '')
                    }
                    data-bs-toggle="slide"
                    onClick={() => toggleSidebar(false)}
                  >
                    <SideMenuIcon icon={children.logo} />
                    <span className="side-menu__label">
                      <span>{children.name}</span>{' '}
                      {children.disabled && <span className="hidden">Coming soon</span>}
                    </span>
                  </NavLink>
                </li>
              )
            })}
          </div>
        )
      })}
    </ul>
  )
}
