import { useEffect } from 'react'
import { Button } from 'react-bootstrap'
import { Helmet } from 'react-helmet-async'
import { useAuth } from 'react-oidc-context'
import { useLocation, useNavigate } from 'react-router-dom'

export const UnauthorizedPage = () => {
  const auth = useAuth()
  const location = useLocation()
  const navigate = useNavigate()

  useEffect(() => {
    if (location.pathname !== '/unauthorized') navigate('/unauthorized')
  }, [location.pathname])

  return (
    <>
      <Helmet>
        <title>Unauthorized</title>
      </Helmet>
      <div className="mt-0">
        <div className="page">
          <div className="page-content error-page error2">
            <div className="container text-center">
              <div className="error-template">
                <h1 className="display-4 fw-bold mb-5">Unauthorized</h1>
                <h5 className="error-details">
                  {auth.isAuthenticated ? `${auth.user?.profile.name}, you` : 'You'} do not have
                  access to this page. Contact an administrator at ZData.
                </h5>
                <br />
                <div className="text-center">
                  <Button
                    variant="primary"
                    onClick={() =>
                      auth.isAuthenticated ? auth.signinRedirect() : auth.signoutRedirect()
                    }
                  >
                    <i className="fa fa-long-arrow-left"></i> Try again
                  </Button>
                </div>
              </div>
            </div>
          </div>
        </div>
      </div>
    </>
  )
}
