import create, { GetState, SetState, StoreApi } from 'zustand'
import { persist } from 'zustand/middleware'
import { createThemeSlice, IThemeSlice } from './createThemeSlice'
import { createAuthSlice, IAuthSlice } from './createAuthSlice'

export const useThemeStore = create<IThemeSlice>(
  persist(
    (set, get, api) => ({
      ...createThemeSlice(
        set as unknown as SetState<IThemeSlice>,
        get as GetState<IThemeSlice>,
        api as unknown as StoreApi<IThemeSlice>,
      ),
    }),
    {
      name: 'theme-storage',
    },
  ),
)

export const useAuthStore = create<IAuthSlice>(
  persist(
    (set, get, api) => ({
      ...createAuthSlice(
        set as unknown as SetState<IAuthSlice>,
        get as GetState<IAuthSlice>,
        api as unknown as StoreApi<IAuthSlice>,
      ),
    }),
    {
      name: 'auth-storage',
      getStorage: () => sessionStorage,
    },
  ),
)
