import { statisticsAPI } from './API'
import WidgetParameters from 'shared/interfaces/widget/widget-parameters'
import WidgetResponse from 'shared/interfaces/widget/widget-response.interface'

/**
 * API Call to fetch widget data (active accounts, clients and users).
 * Maybe refactor into three different API calls later.
 * @param {string} resourceId ID of requested resource
 * @param {string} resourceType Type of requested resource
 * @param {string} widgetType Type of requested widget
 * @param {string} from Date from, must be in a RFC 3339 compliant format.
 * @param {string} to Date to, must be in a RFC 3339 compliant format.
 *
 * @returns {promise} Promise of an array of dates with client counts.
 */
export const getWidget = async ({
  resourceId,
  resourceType,
  widgetType,
  from,
  to,
  take,
  skip,
}: WidgetParameters) => {
  let query = `/${widgetType}`
  if (widgetType == 'users' && !resourceId) query += `/all`
  else if (resourceId) query += `/${resourceId}`

  if (widgetType == 'users') query += '/active'

  if (resourceId) query += `?resourceType=${resourceType}`
  else query += '?'

  if (from) query += `&fromDate=${from}`
  if (to) query += `&toDate=${to}`
  if (take) query += `&take=${take}`
  if (skip) query += `&skip=${skip}`

  return (await statisticsAPI.get<WidgetResponse>(query)).data
}
