import { statisticsAPI } from '../API'
import { Dates } from 'utils'
import AggregatedStatistics from 'shared/interfaces/graph/aggregated-statistics.interface'
import StatisticsParameters from 'shared/interfaces/graph/statistics-parameters.interface'

const getTimeType = (timeType: string): string => {
  const opts = timeType.split('-')
  return opts.length === 2 ? opts[1] : timeType
}

const getStatisticsFromDateByTimeType = (timeType: string | undefined): string | undefined => {
  switch (timeType) {
    case '7-day':
      return Dates.last7days

    default:
      return undefined
  }
}

export const getStatistics = async (args: StatisticsParameters) => {
  let query = `/statistics/aggregate`

  if (args.resourceId) query += `/${args.resourceId}?resourceType=${args.resourceType}&`
  else query += '?'

  query += `eventType=${args.eventType}&timeType=${getTimeType(args.timeType)}`

  const fromDate = args.fromDate || getStatisticsFromDateByTimeType(args.timeType)
  if (fromDate) query += `&fromDate=${fromDate}`
  if (args.toDate) query += `&toDate=${args.toDate}`
  if (args.take) query += `&take=${args.take}`

  return (await statisticsAPI.get<AggregatedStatistics[]>(query)).data
}
