import dayjs from 'dayjs'

/**
 * Returns a number formatted with a chosen amount of decimal places.
 * @param number {number}
 * @param decimals {number}
 * @returns {string}
 */
export const formatNumber = (number: number, decimals?: number): string =>
  decimals == 0
    ? Math.round(number).toString()
    : number.toLocaleString('nb-NO', { maximumFractionDigits: decimals || 2 })

export const capitalize = (string: string): string => {
  const [firstLetter, ...restOfWord] = string
  return firstLetter.toUpperCase() + restOfWord.join('')
}

export const toggleSidebar = (force: boolean): void => {
  if (force || document.body.classList.contains('sidebar-gone'))
    document.body.classList.toggle('sidenav-toggled')
}

/**
 * Returns the difference between two numbers as a percentage
 * @param a {number}
 * @param b {number}
 * @returns {number}
 */
export const percentageDifference = (a: number, b: number): number => {
  if (a == 0 || b == 0) return 0
  const difference = (100 * (a - b)) / ((a + b) / 2)
  return isNaN(difference) ? 0 : difference
}

/**
 * Sums an array that contains numeric values, optionally through a property.
 * @param arr {array}
 * @param item {string}
 * @returns {number}
 */
// eslint-disable-next-line @typescript-eslint/no-explicit-any
export const sumArray = (arr: Array<any> | undefined, item?: string): number => {
  if (arr == undefined) return 0
  return item ? arr.reduce((sum, x) => sum + x[`${item}`], 0) : arr.reduce((sum, x) => sum + x, 0)
}

/**
 * Returns a given date in a RFC 3339 compliant string
 */
export const Dates = {
  today: dayjs().format('YYYY-MM-DD'),
  yesterday: dayjs().format('YYYY-MM-DD'),
  last7days: dayjs().subtract(6, 'd').format('YYYY-MM-DD'),
  last14days: dayjs().subtract(13, 'd').format('YYYY-MM-DD'),
  lastMonth: dayjs().subtract(1, 'm').add(1, 'd').format('YYYY-MM-DD'),
}
