import dayjs, { Dayjs, ManipulateType } from 'dayjs'

import AggregatedStatistics from 'shared/interfaces/graph/aggregated-statistics.interface'
import GroupedDatasets from 'shared/interfaces/chartjs/datasets.interface'

const getStatisticsDateFormat = (daysDifference: number): string => {
  if (daysDifference === 1) return 'HH'
  else return 'DD/MM'
}

export const getFilterTimeType = (fromDate: Date, toDate: Date): string => {
  return dayjs(fromDate).isSame(toDate, 'day') ? 'hour' : 'day'
}

const resetUTCHour = (date: Dayjs): Dayjs => {
  return dayjs(new Date(date.year(), date.month(), date.date() + 1).setUTCHours(12, 0, 0, 0))
}

const setDate = (date: Dayjs, resetHour: boolean): string => {
  const time = resetHour ? resetUTCHour(date) : dayjs(date)

  return time.set('minute', 0).set('second', 0).set('millisecond', 0).toISOString()
}

export const groupStatisticsByDate = (
  data: AggregatedStatistics[],
  fromDate: Date,
  toDate: Date,
): GroupedDatasets => {
  const filterTimeType = getFilterTimeType(fromDate, toDate)

  const daysDifference = Math.abs(dayjs(fromDate).diff(toDate, 'day')) + 1

  //* Go to end of day if timeType is hour to get the whole day
  toDate = filterTimeType === 'hour' ? dayjs(toDate).endOf('day').toDate() : toDate

  //* Get date format based on filter type
  const dateFormat = getStatisticsDateFormat(daysDifference)

  //* Should reset hour to UTC 12
  const resetHourToNoon = !filterTimeType.includes('hour')

  //* Generate a list of all dates based on filter type and date format
  const labels = Array(daysDifference === 1 ? 24 : daysDifference)
    .fill('0')
    .map((_, index) =>
      setDate(dayjs(toDate).subtract(index, filterTimeType as ManipulateType), resetHourToNoon),
    )
    .reverse()

  //* Count events for each date
  const count = labels.map(label => {
    const date = data.find(x => setDate(dayjs(x.date), resetHourToNoon) === label)
    return date ? date.count : 0
  })

  return {
    labels: labels.map(label => dayjs(label).format(dateFormat)),
    count,
  }
}
