import dayjs, { Dayjs } from 'dayjs'

import GroupedDatasets from 'shared/interfaces/chartjs/datasets.interface'
import WidgetData from 'shared/interfaces/widget/widget-data.interface'

const getWidgetDateFormat = (daysDifference: number): string => {
  if (daysDifference < 15) return 'ddd'
  else return 'DD/MM'
}

const resetUTCHour = (date: Dayjs): Dayjs => {
  return dayjs(new Date(date.year(), date.month(), date.date() + 1).setUTCHours(12, 0, 0, 0))
}

const setDate = (date: Dayjs): string => {
  const time = resetUTCHour(date)
  return time.set('minute', 0).set('second', 0).set('millisecond', 0).toISOString()
}

export const groupWidgetDataByDate = (
  data: WidgetData[],
  fromDate: Date,
  toDate: Date,
): GroupedDatasets => {
  const daysDifference = Math.abs(dayjs(fromDate).diff(toDate, 'day'))

  //* Get date format based on filter type
  const dateFormat = getWidgetDateFormat(daysDifference)

  //* Generate a list of all dates based on filter type and date format
  const labels = Array(daysDifference)
    .fill('0')
    .map((_, index) => setDate(dayjs(toDate).subtract(index, 'day')))
    .reverse()

  //* Count events for each date
  const count = labels.map(label => {
    const match = data.find(x => setDate(dayjs(x.date)) === label)
    return match ? match.count : 0
  })

  return {
    labels: labels.map(label => dayjs(label).format(dateFormat)),
    count: count,
  }
}
